=========
md2reveal
=========

This tool converts markdown to reveal.js.
(Requires no additional syntax)

It will split sections by h1/h2/h3 tags.
Check demo on https://www.liriansu.com/md2reveal

Source code is hosted on https://github.com/LKI/md2reveal

============
Installation
============

Use pip to install md2reveal:

::

    pip install md2reveal

Or install it directly by shell script:

::

    git clone https://github.com/LKI/md2reveal ~/.md2reveal
    ~/.md2reveal/setup.sh /usr/bin/md2reveal

Then you can use md2reveal command

::

    md2reveal hello.md
